.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API

0.2.0 (2018-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.1.0...v0.2.0>`_

* Improved REST API filters

0.2.1 (2018-01-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.2.0...v0.2.1>`_

* Updated packages and fixed issue with migrations

0.2.2 (2018-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.2.1...v0.2.2>`_

* Fixed route names for SimpleRouter

0.3.0 (2018-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.2.2...v0.3.0>`_

0.3.1 (2018-03-14)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.3.0...v0.3.1>`_

* Updated requirements
* Updated choices for file type choices to be more comprehensive

0.4.0 (2018-03-23)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.3.1...v0.4.0>`_

* Added property for File model for easy access to display type


0.5.0 (2018-03-30)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.4.0...v0.5.0>`_

* Added additional file type choices

0.6.0 (2018-04-03)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.5.0...v0.6.0>`_

* Added support for GraphQL

0.7.0 (2018-04-07)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.6.0...v0.7.0>`_

* Added support for GraphQL

0.7.1 (2018-04-18)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.7.0...v0.7.1>`_

* #27 - Fixed file type issues
* Updated 3rd party libs

0.7.2 (2018-05-16)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.7.1...v0.7.2>`_

* Updated 3rd party libs
* Updated setup.py to read from requirements.txt

0.8.0 (2018-06-01)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.7.2...v0.8.0>`_

* Removed support for GraphQL - useless here.  Applications using GraphQL can set up schema with models

0.8.1 (2018-08-13)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-data-sources-tracking/compare/v0.8.0...v0.8.1>`_

* Updated 3rd party requirements. Some requirements had changed so it was causing failures
